@@ -49,7 +49,7 @@ test_type test_array[]={
    ASN1_SYNTAX_ERROR,_FILE_":6: parse error near 'TEST_PARSER'"},
   {6,"TEST_PARSER { }",ASN1_SUCCESS,""},
 
-  /* Test MAX_NAME_SIZE (128) */
+  /* Test ASN1_MAX_NAME_SIZE (128) */
   {12,"a1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567 ::= INTEGER",
    ASN1_SUCCESS,""},
   {12,"a12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678 ::= INTEGER",
@@ -145,7 +145,7 @@ main(int argc,char *argv[])
 {
   asn1_retCode result;
   ASN1_TYPE definitions=ASN1_TYPE_EMPTY;
-  char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
+  char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   test_type *test;
   int errorCounter=0,testCounter=0;
 
@@ -162,7 +162,7 @@ main(int argc,char *argv[])
 
   if(result!=ASN1_SUCCESS){
     printf("File '%s' not correct\n",fileCorrectName);
-    libtasn1_perror(result);
+    asn1_perror(result);
     printf("ErrorDescription = %s\n\n",errorDescription);
     exit(1);
   }
@@ -189,9 +189,9 @@ main(int argc,char *argv[])
       errorCounter++;
       printf("ERROR N. %d:\n",errorCounter);
       printf("  Line %d - %s\n",test->lineNumber,test->line);
-      printf("  Error expected: %s - %s\n",libtasn1_strerror(test->errorNumber),
+      printf("  Error expected: %s - %s\n",asn1_strerror(test->errorNumber),
              test->errorDescription);
-      printf("  Error detected: %s - %s\n\n",libtasn1_strerror(result),
+      printf("  Error detected: %s - %s\n\n",asn1_strerror(result),
              errorDescription);
     }
  
